@@ -38,7 +38,7 @@ def run_cached(cmd, cache_duration_secs=None):
     env_vars.update({
         'AWS_ACCESS_KEY_ID': os.environ.get('AWS_ACCESS_KEY_ID') or 'test',
         'AWS_SECRET_ACCESS_KEY': os.environ.get('AWS_SECRET_ACCESS_KEY') or 'test',
-        'AWS_DEFAULT_REGION': os.environ.get('AWS_DEFAULT_REGION') or DEFAULT_REGION,
+        'AWS_DEFAULT_REGION': DEFAULT_REGION or os.environ.get('AWS_DEFAULT_REGION'),
         'PYTHONWARNINGS': 'ignore:Unverified HTTPS request'
     })
     tmp_file_path = new_tmp_file()
