@@ -8,9 +8,10 @@ from moto.core.models import CloudFormationModel
 from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
 from localstack.constants import AWS_REGION_US_EAST_1, LOCALHOST
 from localstack.utils.aws import aws_stack
-from localstack.utils.common import camel_to_snake_case
+from localstack.utils.common import camel_to_snake_case, select_attributes
 from localstack.services.cloudformation.deployment_utils import (
-    PLACEHOLDER_RESOURCE_NAME, remove_none_values, params_list_to_dict, lambda_keys_to_lower)
+    PLACEHOLDER_RESOURCE_NAME, remove_none_values, params_list_to_dict, lambda_keys_to_lower,
+    merge_parameters, params_dict_to_list, select_parameters)
 
 LOG = logging.getLogger(__name__)
 
@@ -107,6 +108,21 @@ class GenericBaseModel(CloudFormationModel):
     # GENERIC UTIL METHODS
     # ----------------------
 
+    def fetch_and_update_state(self, *args, **kwargs):
+        from localstack.utils.cloudformation import template_deployer
+        try:
+            state = self.fetch_state(*args, **kwargs)
+            self.update_state(state)
+            return state
+        except Exception as e:
+            if not template_deployer.check_not_found_exception(e, self.resource_type, self.properties):
+                LOG.debug('Unable to fetch state for resource %s: %s' % (self, e))
+
+    def fetch_state_if_missing(self, *args, **kwargs):
+        if not self.state:
+            self.fetch_and_update_state(*args, **kwargs)
+        return self.state
+
     def set_resource_state(self, state):
         """ Set the deployment state of this resource. """
         self.state = state or {}
@@ -310,6 +326,9 @@ class LambdaEventSourceMapping(GenericBaseModel):
             raise Exception('ResourceNotFound')
         return mapping[0]
 
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        return self.props.get('UUID')
+
 
 class LambdaPermission(GenericBaseModel):
     @staticmethod
@@ -338,6 +357,37 @@ class LambdaPermission(GenericBaseModel):
         return self.props.get('Sid')
 
 
+class LambdaEventInvokeConfig(GenericBaseModel):
+    @staticmethod
+    def cloudformation_type():
+        return 'AWS::Lambda::EventInvokeConfig'
+
+    def fetch_state(self, stack_name, resources):
+        client = aws_stack.connect_to_service('lambda')
+        props = self.props
+        result = client.get_function_event_invoke_config(
+            FunctionName=props.get('FunctionName'), Qualifier=props.get('FunctionName', '$LATEST'))
+        return result
+
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        props = self.props
+        return 'lambdaconfig-%s-%s' % (props.get('FunctionName'), props.get('Qualifier'))
+
+    def get_deploy_templates():
+        return {
+            'create': {
+                'function': 'put_function_event_invoke_config'
+            },
+            'delete': {
+                'function': 'delete_function_event_invoke_config',
+                'parameters': {
+                    'FunctionName': 'FunctionName',
+                    'Qualifier': 'Qualifier'
+                }
+            }
+        }
+
+
 class ElasticsearchDomain(GenericBaseModel):
     @staticmethod
     def cloudformation_type():
@@ -383,6 +433,72 @@ class KinesisStream(GenericBaseModel):
         return result
 
 
+class KinesisStreamConsumer(GenericBaseModel):
+    @staticmethod
+    def cloudformation_type():
+        return 'AWS::Kinesis::StreamConsumer'
+
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        return self.props.get('ConsumerARN')
+
+    def fetch_state(self, stack_name, resources):
+        props = self.props
+        stream_arn = self.resolve_refs_recursively(stack_name, props['StreamARN'], resources)
+        result = aws_stack.connect_to_service('kinesis').list_stream_consumers(StreamARN=stream_arn)
+        result = [r for r in result['Consumers'] if r['ConsumerName'] == props['ConsumerName']]
+        return (result or [None])[0]
+
+    def get_deploy_templates():
+        return {
+            'create': {
+                'function': 'register_stream_consumer'
+            },
+            'delete': {
+                'function': 'deregister_stream_consumer'
+            }
+        }
+
+
+class Route53RecordSet(GenericBaseModel):
+    @staticmethod
+    def cloudformation_type():
+        return 'AWS::Route53::RecordSet'
+
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        return self.props.get('Name')  # Ref attribute is the domain name itself
+
+    def fetch_state(self, stack_name, resources):
+        route53 = aws_stack.connect_to_service('route53')
+        props = self.props
+        result = route53.list_resource_record_sets(HostedZoneId=props['HostedZoneId'])['ResourceRecordSets']
+        result = [r for r in result if r['Name'] == props['Name'] and r['Type'] == props['Type']]
+        return (result or [None])[0]
+
+    def get_deploy_templates():
+        def param_change_batch(params, **kwargs):
+            attr_names = ['Name', 'Type', 'SetIdentifier', 'Weight', 'Region', 'GeoLocation',
+                'Failover', 'MultiValueAnswer', 'TTL', 'ResourceRecords', 'AliasTarget', 'HealthCheckId']
+            attrs = select_attributes(params, attr_names)
+            alias_target = attrs.get('AliasTarget', {})
+            alias_target['EvaluateTargetHealth'] = alias_target.get('EvaluateTargetHealth', False)
+            return {
+                'Comment': params.get('Comment', ''),
+                'Changes': [{
+                    'Action': 'CREATE',
+                    'ResourceRecordSet': attrs
+                }]
+            }
+        return {
+            'create': {
+                'function': 'change_resource_record_sets',
+                'parameters': {
+                    'HostedZoneId': 'HostedZoneId',
+                    'ChangeBatch': param_change_batch
+                }
+            }
+        }
+
+
 class SFNStateMachine(GenericBaseModel):
     @staticmethod
     def cloudformation_type():
@@ -945,6 +1061,9 @@ class SNSSubscription(GenericBaseModel):
     def cloudformation_type():
         return 'AWS::SNS::Subscription'
 
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        return self.props.get('SubscriptionArn')
+
     def fetch_state(self, stack_name, resources):
         props = self.props
         topic_arn = props.get('TopicArn')
@@ -957,6 +1076,38 @@ class SNSSubscription(GenericBaseModel):
         # TODO: use get_subscription_attributes to compare FilterPolicy
         return result[0] if result else None
 
+    @staticmethod
+    def get_deploy_templates():
+        def sns_subscription_arn(params, resources, resource_id, **kwargs):
+            resource = resources[resource_id]
+            return resource['PhysicalResourceId']
+
+        def sns_subscription_params(params, **kwargs):
+            def attr_val(val):
+                return json.dumps(val) if isinstance(val, (dict, list)) else str(val)
+
+            attrs = ['DeliveryPolicy', 'FilterPolicy', 'RawMessageDelivery', 'RedrivePolicy']
+            result = dict([(a, attr_val(params[a])) for a in attrs if a in params])
+            return result
+
+        return {
+            'create': {
+                'function': 'subscribe',
+                'parameters': {
+                    'TopicArn': 'TopicArn',
+                    'Protocol': 'Protocol',
+                    'Endpoint': 'Endpoint',
+                    'Attributes': sns_subscription_params
+                }
+            },
+            'delete': {
+                'function': 'unsubscribe',
+                'parameters': {
+                    'SubscriptionArn': sns_subscription_arn
+                }
+            }
+        }
+
 
 class DynamoDBTable(GenericBaseModel):
     @staticmethod
@@ -986,11 +1137,24 @@ class SSMParameter(GenericBaseModel):
     def cloudformation_type():
         return 'AWS::SSM::Parameter'
 
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        return self.props.get('Name') or self.resource_id
+
     def fetch_state(self, stack_name, resources):
         param_name = self.props.get('Name') or self.resource_id
         param_name = self.resolve_refs_recursively(stack_name, param_name, resources)
         return aws_stack.connect_to_service('ssm').get_parameter(Name=param_name)['Parameter']
 
+    @staticmethod
+    def get_deploy_templates():
+        return {
+            'create': {
+                'function': 'put_parameter',
+                'parameters': merge_parameters(params_dict_to_list('Tags', wrapper='Tags'), select_parameters(
+                    'Name', 'Type', 'Value', 'Description', 'AllowedPattern', 'Policies', 'Tier'))
+            }
+        }
+
 
 class SecretsManagerSecret(GenericBaseModel):
     @staticmethod
