@@ -1,4 +1,3 @@
-# noqa
 import os
 import re
 import sys
@@ -20,10 +19,9 @@ from localstack.utils.common import (TMP_THREADS, run, get_free_tcp_port, is_lin
 from localstack.utils.server import multiserver
 from localstack.utils.testutil import is_local_test_mode
 from localstack.utils.bootstrap import (
-    setup_logging, is_debug, canonicalize_api_names, load_plugins, in_ci)
+    setup_logging, canonicalize_api_names, load_plugins, in_ci)
 from localstack.utils.analytics import event_publisher
 from localstack.services import generic_proxy, install
-from localstack.services.es import es_api
 from localstack.services.plugins import SERVICE_PLUGINS, record_service_health, check_infra
 from localstack.services.firehose import firehose_api
 from localstack.services.awslambda import lambda_api
@@ -98,28 +96,6 @@ def start_sts(port=None, asynchronous=False):
     return start_moto_server('sts', port, name='STS', asynchronous=asynchronous)
 
 
-def start_redshift(port=None, asynchronous=False):
-    port = port or config.PORT_REDSHIFT
-    return start_moto_server('redshift', port, name='Redshift', asynchronous=asynchronous)
-
-
-def start_acm(port=None, asynchronous=False):
-    port = port or config.PORT_ACM
-    return start_moto_server('acm', port, name='ACM', asynchronous=asynchronous)
-
-
-# TODO still needed?
-def start_ses(port=None, asynchronous=False):
-    port = port or config.PORT_SES
-    return start_moto_server('ses', port, name='SES', asynchronous=asynchronous)
-
-
-# TODO move to es_starter.py?
-def start_elasticsearch_service(port=None, asynchronous=False):
-    port = port or config.PORT_ES
-    return start_local_api('ES', port, api='es', method=es_api.serve, asynchronous=asynchronous)
-
-
 def start_firehose(port=None, asynchronous=False):
     port = port or config.PORT_FIREHOSE
     return start_local_api('Firehose', port, api='firehose', method=firehose_api.serve, asynchronous=asynchronous)
@@ -261,7 +237,7 @@ def register_signal_handlers():
 def do_run(cmd, asynchronous, print_output=None, env_vars={}):
     sys.stdout.flush()
     if asynchronous:
-        if is_debug() and print_output is None:
+        if config.DEBUG and print_output is None:
             print_output = True
         outfile = subprocess.PIPE if print_output else None
         t = ShellCommandThread(cmd, outfile=outfile, env_vars=env_vars)
@@ -293,7 +269,7 @@ def start_proxy(port, backend_url, update_listener=None, quiet=False, params={},
 def start_moto_server(key, port, name=None, backend_port=None, asynchronous=False, update_listener=None):
     if not name:
         name = key
-    print('Starting mock %s service on %s ...' % (name, edge_ports_info()))
+    log_startup_message(name)
     if not backend_port:
         if config.FORWARD_EDGE_INMEM:
             backend_port = multiserver.get_moto_server_port()
@@ -315,7 +291,7 @@ def start_moto_server_separate(key, port, name=None, backend_port=None, asynchro
 
 
 def start_local_api(name, port, api, method, asynchronous=False):
-    print('Starting mock %s service on %s ...' % (name, edge_ports_info()))
+    log_startup_message(name)
     if config.FORWARD_EDGE_INMEM:
         port = get_free_tcp_port()
         PROXY_LISTENERS[api] = (api, port, None)
@@ -345,6 +321,10 @@ def stop_infra(debug=False):
     # check_infra(retries=2, expect_shutdown=True)
 
 
+def log_startup_message(service):
+    print('Starting mock %s service on %s ...' % (service, edge_ports_info()))
+
+
 def check_aws_credentials():
     session = boto3.Session()
     credentials = None
@@ -364,7 +344,6 @@ def check_aws_credentials():
 # MAIN STARTUP
 # -------------
 
-
 def start_infra(asynchronous=False, apis=None):
     try:
         os.environ[LOCALSTACK_INFRA_PROCESS] = '1'
