@@ -1,5 +1,6 @@
 import re
 import json
+import time
 import random
 import cbor2
 from requests.models import Response
@@ -10,16 +11,12 @@ from localstack.utils.common import to_str, json_safe, clone, epoch_timestamp, n
 from localstack.utils.analytics import event_publisher
 from localstack.services.awslambda import lambda_api
 from localstack.services.generic_proxy import ProxyListener
+from localstack.utils.aws.aws_responses import convert_to_binary_event_payload
 
-# action headers
+# action headers (should be left here - imported/required by other files)
 ACTION_PREFIX = 'Kinesis_20131202'
-ACTION_PUT_RECORD = '%s.PutRecord' % ACTION_PREFIX
 ACTION_PUT_RECORDS = '%s.PutRecords' % ACTION_PREFIX
 ACTION_LIST_STREAMS = '%s.ListStreams' % ACTION_PREFIX
-ACTION_CREATE_STREAM = '%s.CreateStream' % ACTION_PREFIX
-ACTION_DELETE_STREAM = '%s.DeleteStream' % ACTION_PREFIX
-ACTION_UPDATE_SHARD_COUNT = '%s.UpdateShardCount' % ACTION_PREFIX
-ACTION_GET_RECORDS = '%s.GetRecords' % ACTION_PREFIX
 
 # list of stream consumer details
 STREAM_CONSUMERS = []
@@ -68,26 +65,29 @@ class ProxyListenerKinesis(ProxyListener):
                 }
             }
             return result
+        elif action == 'SubscribeToShard':
+            result = subscribe_to_shard(data)
+            return result
 
         if random.random() < config.KINESIS_ERROR_PROBABILITY:
-            action = headers.get('X-Amz-Target')
-            if action in [ACTION_PUT_RECORD, ACTION_PUT_RECORDS]:
+            if action in ['PutRecord', 'PutRecords']:
                 return kinesis_error_response(data, action)
         return True
 
     def return_response(self, method, path, data, headers, response):
-        action = headers.get('X-Amz-Target')
+        action = headers.get('X-Amz-Target', '').split('.')[-1]
         data = self.decode_content(data or '{}')
         response._content = self.replace_in_encoded(response.content or '')
         records = []
-        if action in (ACTION_CREATE_STREAM, ACTION_DELETE_STREAM):
-            event_type = (event_publisher.EVENT_KINESIS_CREATE_STREAM if action == ACTION_CREATE_STREAM
+
+        if action in ('CreateStream', 'DeleteStream'):
+            event_type = (event_publisher.EVENT_KINESIS_CREATE_STREAM if action == 'CreateStream'
                           else event_publisher.EVENT_KINESIS_DELETE_STREAM)
             payload = {'n': event_publisher.get_hash(data.get('StreamName'))}
-            if action == ACTION_CREATE_STREAM:
+            if action == 'CreateStream':
                 payload['s'] = data.get('ShardCount')
             event_publisher.fire_event(event_type, payload=payload)
-        elif action == ACTION_PUT_RECORD:
+        elif action == 'PutRecord':
             response_body = self.decode_content(response.content)
             # Note: avoid adding 'encryptionType':'NONE' in the event_record, as this breaks .NET Lambdas
             event_record = {
@@ -99,7 +99,7 @@ class ProxyListenerKinesis(ProxyListener):
             event_records = [event_record]
             stream_name = data['StreamName']
             lambda_api.process_kinesis_records(event_records, stream_name)
-        elif action == ACTION_PUT_RECORDS:
+        elif action == 'PutRecords':
             event_records = []
             response_body = self.decode_content(response.content)
             if 'Records' in response_body:
@@ -117,7 +117,7 @@ class ProxyListenerKinesis(ProxyListener):
                     event_records.append(event_record)
                 stream_name = data['StreamName']
                 lambda_api.process_kinesis_records(event_records, stream_name)
-        elif action == ACTION_UPDATE_SHARD_COUNT:
+        elif action == 'UpdateShardCount':
             # Currently kinesalite, which backs the Kinesis implementation for localstack, does
             # not support UpdateShardCount:
             # https://github.com/mhart/kinesalite/issues/61
@@ -138,7 +138,7 @@ class ProxyListenerKinesis(ProxyListener):
             response.encoding = 'UTF-8'
             response._content = json.dumps(content)
             return response
-        elif action == ACTION_GET_RECORDS:
+        elif action == 'GetRecords':
             sdk_v2 = self.sdk_is_v2(headers.get('User-Agent', '').split(' ')[0])
             results, encoding_type = self.decode_content(response.content, True)
 
@@ -150,13 +150,9 @@ class ProxyListenerKinesis(ProxyListener):
                 if sdk_v2:
                     record['ApproximateArrivalTimestamp'] = int(record['ApproximateArrivalTimestamp'])
                 if not isinstance(record['Data'], str):
-                    record['Data'] = bytearray(record['Data']['data'])
-
-            if encoding_type == APPLICATION_CBOR:
-                response._content = cbor2.dumps(results)
-            else:
-                response._content = json.dumps(results)
+                    record['Data'] = bytearray(record['Data']['data']).decode('utf-8')
 
+            response._content = cbor2.dumps(results) if encoding_type == APPLICATION_CBOR else json.dumps(results)
             return response
 
     def sdk_is_v2(self, user_agent):
@@ -168,15 +164,15 @@ class ProxyListenerKinesis(ProxyListener):
         if not data:
             return ''
 
+        def _replace(_data):
+            return re.sub(r'arn:aws:kinesis:[^:]+:', 'arn:aws:kinesis:%s:' % aws_stack.get_region(), _data)
         decoded, type_encoding = self.decode_content(data, True)
 
         if type_encoding == APPLICATION_JSON:
-            return re.sub(r'arn:aws:kinesis:[^:]+:', 'arn:aws:kinesis:%s:' % aws_stack.get_region(),
-            to_str(data))
+            return _replace(to_str(data))
 
         if type_encoding == APPLICATION_CBOR:
-            replaced = re.sub(r'arn:aws:kinesis:[^:]+:', 'arn:aws:kinesis:%s:' % aws_stack.get_region(),
-            json.dumps(decoded))
+            replaced = _replace(json.dumps(decoded))
             return cbor2.dumps(json.loads(replaced))
 
     def decode_content(self, data, describe=False):
@@ -194,14 +190,48 @@ class ProxyListenerKinesis(ProxyListener):
         return decoded
 
 
-# instantiate listener
-UPDATE_KINESIS = ProxyListenerKinesis()
+def subscribe_to_shard(data):
+    kinesis = aws_stack.connect_to_service('kinesis')
+    stream_name = find_stream_for_consumer(data['ConsumerARN'])
+    iter_type = data['StartingPosition']['Type']
+    iterator = kinesis.get_shard_iterator(StreamName=stream_name,
+        ShardId=data['ShardId'], ShardIteratorType=iter_type)['ShardIterator']
+
+    def send_events():
+        yield convert_to_binary_event_payload('', event_type='initial-response')
+        iter = iterator
+        # TODO: find better way to run loop up to max 5 minutes (until connection terminates)!
+        for i in range(5 * 60):
+            result = kinesis.get_records(ShardIterator=iter)
+            iter = result.get('NextShardIterator')
+            records = result.get('Records', [])
+            for record in records:
+                record['ApproximateArrivalTimestamp'] = record['ApproximateArrivalTimestamp'].timestamp()
+                record['Data'] = to_str(record['Data'])
+            if not records:
+                time.sleep(1)
+                continue
+            result = json.dumps({'Records': records})
+            yield convert_to_binary_event_payload(result, event_type='SubscribeToShardEvent')
+
+    headers = {}
+    return send_events(), headers
+
+
+def find_stream_for_consumer(consumer_arn):
+    kinesis = aws_stack.connect_to_service('kinesis')
+    for stream_name in kinesis.list_streams()['StreamNames']:
+        stream_arn = aws_stack.kinesis_stream_arn(stream_name)
+        for cons in kinesis.list_stream_consumers(StreamARN=stream_arn)['Consumers']:
+            if cons['ConsumerARN'] == consumer_arn:
+                return stream_name
+    raise Exception('Unable to find stream for stream consumer %s' % consumer_arn)
 
 
 def kinesis_error_response(data, action):
     error_response = Response()
 
-    if action == ACTION_PUT_RECORD:
+    if action == 'PutRecord':
         error_response.status_code = 400
         content = {
             'ErrorCode': 'ProvisionedThroughputExceededException',
@@ -218,3 +248,7 @@ def kinesis_error_response(data, action):
 
     error_response._content = json.dumps(content)
     return error_response
+
+
+# instantiate listener
+UPDATE_KINESIS = ProxyListenerKinesis()
