@@ -156,7 +156,7 @@ def get_event_message(event_name, bucket_name, file_name='testfile.txt', etag=''
     bucket_name = normalize_bucket_name(bucket_name)
     return {
         'Records': [{
-            'eventVersion': '2.0',
+            'eventVersion': '2.1',
             'eventSource': 'aws:s3',
             'awsRegion': aws_stack.get_region(),
             'eventTime': timestamp_millis(),
@@ -474,11 +474,14 @@ def append_last_modified_headers(response, content=None):
 
 def append_list_objects_marker(method, path, data, response):
     if 'marker=' in path:
+        marker = ''
         content = to_str(response.content)
         if '<ListBucketResult' in content and '<Marker>' not in content:
             parsed = urlparse.urlparse(path)
             query_map = urlparse.parse_qs(parsed.query)
-            insert = '<Marker>%s</Marker>' % query_map.get('marker')[0]
+            if query_map.get('marker') and query_map.get('marker')[0]:
+                marker = query_map.get('marker')[0]
+            insert = '<Marker>%s</Marker>' % marker
             response._content = content.replace('</ListBucketResult>', '%s</ListBucketResult>' % insert)
             response.headers.pop('Content-Length', None)
 
@@ -508,6 +511,9 @@ def fix_range_content_type(bucket_name, path, headers, response):
     if 'Range' not in headers:
         return
 
+    if response.status_code >= 400:
+        return
+
     s3_client = aws_stack.connect_to_service('s3')
     path = urlparse.unquote(path)
     key_name = get_key_name(path, headers)
@@ -724,6 +730,16 @@ def set_lifecycle(bucket_name, lifecycle):
     return 200
 
 
+def delete_lifecycle(bucket_name):
+    bucket_name = normalize_bucket_name(bucket_name)
+    exists, code, body = is_bucket_available(bucket_name)
+    if not exists:
+        return requests_response(body, status_code=code)
+
+    if BUCKET_LIFECYCLE.get(bucket_name):
+        BUCKET_LIFECYCLE.pop(bucket_name)
+
+
 def set_replication(bucket_name, replication):
     bucket_name = normalize_bucket_name(bucket_name)
     exists, code, body = is_bucket_available(bucket_name)
@@ -1175,6 +1191,8 @@ class ProxyListenerS3(PersistingProxyListener):
                 return get_lifecycle(bucket)
             if method == 'PUT':
                 return set_lifecycle(bucket, data)
+            if method == 'DELETE':
+                delete_lifecycle(bucket)
 
         if query == 'replication' or 'replication' in query_map:
             if method == 'GET':
@@ -1194,6 +1212,9 @@ class ProxyListenerS3(PersistingProxyListener):
             if method == 'PUT':
                 return set_object_lock(bucket, data)
 
+        if method == 'DELETE' and re.match(BUCKET_NAME_REGEX, bucket_name):
+            delete_lifecycle(bucket_name)
+
         path_orig_escaped = path_orig.replace('#', '%23')
         if modified_data is not None or headers_changed or path_orig != path_orig_escaped:
             data_to_return = not_none_or(modified_data, data)
