@@ -205,10 +205,7 @@ class LambdaFunction(Component):
             raise Exception('Dead letter queue ARN "%s" requires a valid SQS queue or SNS topic' % target_arn)
 
     def get_function_event_invoke_config(self):
-        response = {
-            'LastModified': timestamp_millis(self.last_modified),
-            'FunctionArn': str(self.id),
-        }
+        response = {}
 
         if self.max_retry_attempts:
             response.update({'MaximumRetryAttempts': self.max_retry_attempts})
@@ -230,7 +227,12 @@ class LambdaFunction(Component):
                         'Destination': self.on_failed_invocation
                     }
                 })
-
+        if not response:
+            return None
+        response.update({
+            'LastModified': timestamp_millis(self.last_modified),
+            'FunctionArn': str(self.id),
+        })
         return response
 
     def clear_function_event_invoke_config(self):
@@ -298,6 +300,9 @@ class LambdaFunction(Component):
         # Example ARN: arn:aws:lambda:aws-region:acct-id:function:helloworld:1
         return self.id.split(':')[6]
 
+    def region(self):
+        return self.id.split(':')[3]
+
     def arn(self):
         return self.id
 
