@@ -171,7 +171,7 @@ def get_local_region():
     if LOCAL_REGION is None:
         session = boto3.session.Session()
         LOCAL_REGION = session.region_name or ''
-    return LOCAL_REGION or config.DEFAULT_REGION
+    return config.DEFAULT_REGION or LOCAL_REGION
 
 
 def is_internal_call_context(headers):
@@ -332,6 +332,10 @@ def inject_test_credentials_into_env(env):
         env[ENV_SECRET_KEY] = 'test'
 
 
+def inject_region_into_env(env, region):
+    env['AWS_REGION'] = region
+
+
 def sqs_queue_url_for_arn(queue_arn):
     if '://' in queue_arn:
         return queue_arn
@@ -941,9 +945,12 @@ def await_stack_completion(stack_name, retries=3, sleep=2, statuses=None):
 # TODO: move to aws_responses.py?
 def extract_tags(req_data):
     tags = []
-    req_tags = {k: v for k, v in req_data.items() if k.startswith('Tags.member.')}
-    for i in range(int(len(req_tags.keys()) / 2)):
-        key = req_tags['Tags.member.' + str(i + 1) + '.Key']
-        value = req_tags['Tags.member.' + str(i + 1) + '.Value']
+    for i in range(1, 200):
+        k1 = 'Tags.member.%s.Key' % i
+        k2 = 'Tags.member.%s.Value' % i
+        key = req_data.get(k1)
+        value = req_data.get(k2, '')
+        if key is None:
+            break
         tags.append({'Key': key, 'Value': value})
     return tags
