@@ -12,7 +12,7 @@ from moto.cloudformation.models import cloudformation_backends
 from localstack import config
 from localstack.utils import common
 from localstack.utils.aws import aws_stack
-from localstack.constants import TEST_AWS_ACCOUNT_ID
+from localstack.constants import TEST_AWS_ACCOUNT_ID, FALSE_STRINGS
 from localstack.services.s3 import s3_listener
 from localstack.utils.common import (
     json_safe, md5, canonical_json, short_uid, to_str, to_bytes, download, mkdir, cp_r, prevent_stack_overflow)
@@ -78,17 +78,6 @@ def rename_params(func, rename_map):
     return do_rename
 
 
-def params_dict_to_list(param_name, key_attr_name='Key', value_attr_name='Value', wrapper=None):
-    def do_replace(params, **kwargs):
-        result = []
-        for key, value in params.get(param_name, {}).items():
-            result.append({key_attr_name: key, value_attr_name: value})
-        if wrapper:
-            result = {wrapper: result}
-        return result
-    return do_replace
-
-
 def get_lambda_code_param(params, **kwargs):
     code = params.get('Code', {})
     zip_file = code.get('ZipFile')
@@ -114,15 +103,6 @@ def get_lambda_code_param(params, **kwargs):
     return code
 
 
-def sns_subscription_params(params, **kwargs):
-    def attr_val(val):
-        return json.dumps(val) if isinstance(val, (dict, list)) else str(val)
-
-    attrs = ['DeliveryPolicy', 'FilterPolicy', 'RawMessageDelivery', 'RedrivePolicy']
-    result = dict([(a, attr_val(params[a])) for a in attrs if a in params])
-    return result
-
-
 def events_put_rule_params(params, **kwargs):
     attrs = ['ScheduleExpression', 'EventPattern', 'State', 'Description', 'Name']
     result = select_parameters(*attrs)(params, **kwargs)
@@ -148,10 +128,6 @@ def es_add_tags_params(params, **kwargs):
     return {'ARN': es_arn, 'TagList': tags}
 
 
-def merge_parameters(func1, func2):
-    return lambda params, **kwargs: common.merge_dicts(func1(params, **kwargs), func2(params, **kwargs))
-
-
 def lambda_permission_params(params, **kwargs):
     result = select_parameters('FunctionName', 'Action', 'Principal')(params, **kwargs)
     result['StatementId'] = common.short_uid()
@@ -241,13 +217,6 @@ RESOURCE_TO_FUNCTION = {
             }
         }
     },
-    'SSM::Parameter': {
-        'create': {
-            'function': 'put_parameter',
-            'parameters': merge_parameters(params_dict_to_list('Tags', wrapper='Tags'), params_select_attributes(
-                'Name', 'Type', 'Value', 'Description', 'AllowedPattern', 'Policies', 'Tier'))
-        }
-    },
     'SecretsManager::Secret': {
         'create': {
             'function': 'create_secret',
@@ -533,17 +502,6 @@ RESOURCE_TO_FUNCTION = {
             }
         }
     },
-    'SNS::Subscription': {
-        'create': {
-            'function': 'subscribe',
-            'parameters': {
-                'TopicArn': 'TopicArn',
-                'Protocol': 'Protocol',
-                'Endpoint': 'Endpoint',
-                'Attributes': sns_subscription_params
-            }
-        }
-    },
     'KMS::Key': {
         'create': {
             'function': 'create_key',
@@ -747,8 +705,7 @@ def retrieve_resource_details(resource_id, resource_status, resources, stack_nam
         resource_class = RESOURCE_MODELS.get(canonical_type)
         if resource_class:
             instance = resource_class(resource)
-            state = instance.fetch_state(stack_name=stack_name, resources=resources)
-            instance.update_state(state)
+            state = instance.fetch_and_update_state(stack_name=stack_name, resources=resources)
             return state
 
         # special case for stack parameters
@@ -773,13 +730,15 @@ def retrieve_resource_details(resource_id, resource_status, resources, stack_nam
     return None
 
 
-def check_not_found_exception(e, resource_type, resource, resource_status):
+def check_not_found_exception(e, resource_type, resource, resource_status=None):
     # we expect this to be a "not found" exception
     markers = ['NoSuchBucket', 'ResourceNotFound', 'NoSuchEntity', 'NotFoundException',
         '404', 'not found', 'not exist']
     if not list(filter(lambda marker, e=e: marker in str(e), markers)):
         LOG.warning('Unexpected error retrieving details for resource %s: %s %s - %s %s' %
             (resource_type, e, ''.join(traceback.format_stack()), resource, resource_status))
+        return False
+    return True
 
 
 def extract_resource_attribute(resource_type, resource_state, attribute, resource_id=None,
@@ -1116,7 +1075,7 @@ def evaluate_resource_condition(resource, stack_name, resources):
     condition = resource.get('Condition')
     if condition:
         condition = evaluate_condition(stack_name, condition, resources)
-        if is_none_or_empty_value(condition):
+        if condition is False or condition in FALSE_STRINGS or is_none_or_empty_value(condition):
             return False
     return True
 
@@ -1374,6 +1333,8 @@ def configure_resource_via_sdk(resource_id, resources, resource_type, func_detai
             resource_type, aws_stack.get_region(), func_details['function'], params))
         result = function(**params)
     except Exception as e:
+        if action_name == 'delete' and check_not_found_exception(e, resource_type, resource):
+            return
         LOG.warning('Error calling %s with params: %s for resource: %s' % (function, params, resource))
         raise e
 
@@ -1538,7 +1499,9 @@ def determine_resource_physical_id(resource_id, resources=None, stack=None, attr
     canonical_type = canonical_resource_type(resource_type)
     resource_class = RESOURCE_MODELS.get(canonical_type)
     if resource_class:
-        result = resource_class(resource).get_physical_resource_id(attribute=attribute)
+        resource_inst = resource_class(resource)
+        resource_inst.fetch_state_if_missing(stack_name=stack_name, resources=resources)
+        result = resource_inst.get_physical_resource_id(attribute=attribute)
         if result:
             return result
 
@@ -1930,15 +1893,15 @@ class TemplateDeployer(object):
             for k, v in parameters.items() if v
         ]
 
-    def apply_changes(self, old_stack, new_stack, stack_name, change_set_id=None, initialize=False):
-        old_resources = old_stack.template['Resources']
+    def apply_changes(self, existing_stack, new_stack, stack_name, change_set_id=None, initialize=False):
+        old_resources = existing_stack.template['Resources']
         new_resources = new_stack.template['Resources']
         self.init_resource_status(old_resources, action='UPDATE')
         deletes = [val for key, val in old_resources.items() if key not in new_resources]
         adds = [val for key, val in new_resources.items() if initialize or key not in old_resources]
         modifies = [val for key, val in new_resources.items() if key in old_resources]
 
-        self.apply_parameter_changes(old_stack, new_stack)
+        self.apply_parameter_changes(existing_stack, new_stack)
 
         # construct changes
         changes = []
@@ -1951,12 +1914,15 @@ class TemplateDeployer(object):
                 change = self.get_change_config(action, item, change_set_id=change_set_id)
                 changes.append(change)
                 if action in ['Modify', 'Add']:
-                    self.merge_properties(item['LogicalResourceId'], old_stack, new_stack)
+                    self.merge_properties(item['LogicalResourceId'], existing_stack, new_stack)
         if not contains_changes:
             raise NoStackUpdates('No updates are to be performed.')
 
+        # merge stack outputs
+        existing_stack.template['Outputs'].update(new_stack.template.get('Outputs', {}))
+
         # start deployment loop
-        return self.apply_changes_in_loop(changes, old_stack, stack_name)
+        return self.apply_changes_in_loop(changes, existing_stack, stack_name)
 
     def apply_changes_in_loop(self, changes, stack, stack_name):
         # apply changes in a retry loop, to resolve resource dependencies and converge to the target state
@@ -2019,6 +1985,11 @@ class TemplateDeployer(object):
         # resolve refs in resource details
         resolve_refs_recursively(stack.stack_name, resource, new_resources)
 
+        # check resource condition, if present
+        if not evaluate_resource_condition(resource, stack.stack_name, new_resources):
+            LOG.debug('Skipping deployment of "%s", as resource condition evaluates to false' % resource_id)
+            return
+
         if action in ['Add', 'Modify']:
             is_deployed = self.is_deployed(resource)
             if action == 'Modify' and not is_deployed:
